Note down the key information.

Ultrathink about any questions that will

- conflicts/contradict/challenge my thinking.
- clarify/disambiguous the description.
- focus on the essence/gist of what's important and ask what can be stripped off.
